@@ -27,14 +27,18 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "DialogProxy.h"
 #include "Util.h"
 
+DialogLoadGRIB *globalDial = NULL;
+
 //-------------------------------------------------------------------------------
-QString DialogLoadGRIB::getFile (QNetworkAccessManager *manager, QWidget *parent,
+QString DialogLoadGRIB::getFile (QNetworkAccessManager *netManager, QWidget *parent,
 						double x0, double y0, double x1, double y1)
 {
-	DialogLoadGRIB dial (manager,parent);
-	dial.setZone (x0, y0, x1, y1);
-	dial.exec ();
-	return dial.savedFileName;
+	if (!globalDial)
+		globalDial = new DialogLoadGRIB(netManager,parent);
+	globalDial->setZone (x0, y0, x1, y1);
+	globalDial->exec ();
+	globalDial->saveParametersSettings ();
+	return globalDial->savedFileName;
 }
 
 //-------------------------------------------------------------------------------
@@ -54,14 +58,13 @@ void DialogLoadGRIB::slotFinished (int)
 }
 
 //-------------------------------------------------------------------------------
-DialogLoadGRIB::DialogLoadGRIB (QNetworkAccessManager *manager, QWidget *parent)
+DialogLoadGRIB::DialogLoadGRIB (QNetworkAccessManager *netManager, QWidget *parent)
 	: DialogBoxBase (parent)
 {
     oldcursor = cursor();
     loadgrib = NULL;
-	networkManager = manager;
+	networkManager = netManager;
 	savedFileName = "";
-	
     setWindowTitle(tr("Download - GRIB"));
     loadInProgress = false;
     QFrame * frameButtonsZone = createFrameButtonsZone(this);
@@ -85,7 +88,6 @@ DialogLoadGRIB::DialogLoadGRIB (QNetworkAccessManager *manager, QWidget *parent)
     QGridLayout  *lay = new QGridLayout(this);
     assert(lay);
     lay->addWidget( frameButtonsZone,1,0, Qt::AlignLeft);
-	
     connect(this, SIGNAL(finished(int)), this, SLOT(slotFinished(int)));
 
     connect(btCancel, SIGNAL(clicked()), this, SLOT(slotBtCancel()));
@@ -94,27 +96,21 @@ DialogLoadGRIB::DialogLoadGRIB (QNetworkAccessManager *manager, QWidget *parent)
     connect(btProxy, SIGNAL(clicked()), this, SLOT(slotBtProxy()));
 
     //------------------------------------------------------
-    connect(sbNorth, SIGNAL(valueChanged(double)),
-            this,  SLOT(slotParameterUpdated()));
-    connect(sbSouth, SIGNAL(valueChanged(double)),
-            this,  SLOT(slotParameterUpdated()));
-    connect(sbWest, SIGNAL(valueChanged(double)),
-            this,  SLOT(slotParameterUpdated()));
-    connect(sbEast, SIGNAL(valueChanged(double)),
-            this,  SLOT(slotParameterUpdated()));
+    connect(sbNorth, SIGNAL(valueChanged(double)), this,  SLOT(slotParameterUpdated()));
+    connect(sbSouth, SIGNAL(valueChanged(double)), this,  SLOT(slotParameterUpdated()));
+    connect(sbWest, SIGNAL(valueChanged(double)), this,  SLOT(slotParameterUpdated()));
+    connect(sbEast, SIGNAL(valueChanged(double)), this,  SLOT(slotParameterUpdated()));
             
-    connect(cbResolution, SIGNAL(activated(int)),
-            this,  SLOT(slotParameterUpdated()));
-    connect(cbInterval, SIGNAL(activated(int)),
-            this,  SLOT(slotParameterUpdated()));
-    connect(cbDays, SIGNAL(activated(int)),
-            this,  SLOT(slotParameterUpdated()));
+    connect(cbResolution, SIGNAL(activated(int)), this,  SLOT(slotParameterUpdated()));
+    connect(cbInterval, SIGNAL(activated(int)), this,  SLOT(slotParameterUpdated()));
+    connect(cbDays, SIGNAL(activated(int)), this,  SLOT(slotParameterUpdated()));
+    connect(cbRunGFS, SIGNAL(activated(int)), this,  SLOT(slotParameterUpdated()));
     
     connect(chkWind, SIGNAL(stateChanged(int)), 	this,  SLOT(slotParameterUpdated()));
     connect(chkPressure, SIGNAL(stateChanged(int)), this,  SLOT(slotParameterUpdated()));
     connect(chkRain, SIGNAL(stateChanged(int)), 	this,  SLOT(slotParameterUpdated()));
     connect(chkCloud, SIGNAL(stateChanged(int)), 	this,  SLOT(slotParameterUpdated()));
-//     connect(chkCloudLayers, SIGNAL(stateChanged(int)), 	this,  SLOT(slotParameterUpdated()));
+	// connect(chkCloudLayers, SIGNAL(stateChanged(int)), 	this,  SLOT(slotParameterUpdated()));
     connect(chkTemp, SIGNAL(stateChanged(int)), 	this,  SLOT(slotParameterUpdated()));
     connect(chkHumid, SIGNAL(stateChanged(int)), 	this,  SLOT(slotParameterUpdated()));
     connect(chkIsotherm0, SIGNAL(stateChanged(int)), this,  SLOT(slotParameterUpdated()));
@@ -132,7 +128,9 @@ DialogLoadGRIB::DialogLoadGRIB (QNetworkAccessManager *manager, QWidget *parent)
     connect(chkAltitude_All, SIGNAL(stateChanged(int)), this, SLOT(slotAltitude_All()));
     connect(chkAltitude200, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
     connect(chkAltitude300, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
+    connect(chkAltitude400, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
     connect(chkAltitude500, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
+    connect(chkAltitude600, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
     connect(chkAltitude700, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
     connect(chkAltitude850, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
     connect(chkAltitude925, SIGNAL(stateChanged(int)), this, SLOT(slotParameterUpdated()));
@@ -156,7 +154,9 @@ void DialogLoadGRIB::slotAltitude_All ()
 	bool check = chkAltitude_All->isChecked ();
 	chkAltitude200->setChecked (check);
 	chkAltitude300->setChecked (check);
+	chkAltitude400->setChecked (check);
 	chkAltitude500->setChecked (check);
+	chkAltitude600->setChecked (check);
 	chkAltitude700->setChecked (check);
 	chkAltitude850->setChecked (check);
 	chkAltitude925->setChecked (check);
@@ -195,10 +195,10 @@ void DialogLoadGRIB::slotGribDataReceived (QByteArray *content, QString fileName
 	else
 		path += "/";
 	savedFileName = "";
-	fileName = fileName + ".bz2";
-    fileName = QFileDialog::getSaveFileName (NULL,
-                 tr("Save GRIB file"), path+fileName, "");
-    if (fileName != "")
+	QFileInfo fi (fileName + ".bz2");
+    fileName = Util::getSaveFileName (NULL,
+                 tr("Save GRIB file"), path+fi.fileName());
+	if (fileName != "")
     {
         QFile saveFile (fileName);
         bool ok;
@@ -282,16 +282,61 @@ void DialogLoadGRIB::slotGribReadProgress(int step, int done, int total)
 			);
     }
 }
-
+//-------------------------------------------------------------------------------
+void DialogLoadGRIB::saveParametersSettings ()
+{
+	Util::setSetting("downloadIndResolution", cbResolution->currentIndex());
+	Util::setSetting("downloadIndInterval",  cbInterval->currentIndex());
+	Util::setSetting("downloadIndNbDays",  cbDays->currentIndex());
+	Util::setSetting("downloadRunGFS",  cbRunGFS->itemData(cbRunGFS->currentIndex()));
+	
+	Util::setSetting("downloadWind",  wind);
+	Util::setSetting("downloadPressure", pressure);
+	Util::setSetting("downloadRain",  rain);
+	Util::setSetting("downloadCloud", cloud);
+	Util::setSetting("downloadCloudLayers", cloudLayers);
+	Util::setSetting("downloadTemp",  temp);
+	Util::setSetting("downloadHumid", humid);
+	Util::setSetting("downloadIsotherm0", isotherm0);
+	
+	Util::setSetting("downloadTempMin",  tempMin);
+	Util::setSetting("downloadTempMax",  tempMax);
+	Util::setSetting("downloadSnowDepth", snowDepth);
+	Util::setSetting("downloadSnowCateg", snowCateg);
+	Util::setSetting("downloadFrzRainCateg", frzRainCateg);
+	Util::setSetting("downloadCAPEsfc", CAPEsfc);
+	Util::setSetting("downloadCINsfc", CINsfc);
+	Util::setSetting("downloadGUSTsfc", GUSTsfc);
+	Util::setSetting("downloadSUNSDsfc", SUNSDsfc);
+	
+	Util::setSetting("downloadAltitudeData200",  chkAltitude200->isChecked());
+	Util::setSetting("downloadAltitudeData300",  chkAltitude300->isChecked());
+	Util::setSetting("downloadAltitudeData400",  chkAltitude400->isChecked());
+	Util::setSetting("downloadAltitudeData500",  chkAltitude500->isChecked());
+	Util::setSetting("downloadAltitudeData600",  chkAltitude600->isChecked());
+	Util::setSetting("downloadAltitudeData700",  chkAltitude700->isChecked());
+	Util::setSetting("downloadAltitudeData850",  chkAltitude850->isChecked());
+	Util::setSetting("downloadAltitudeData925",  chkAltitude925->isChecked());
+	Util::setSetting("downloadSkewtData",  chkAltitude_SkewT->isChecked());
+	
+	Util::setSetting("downloadFnmocWW3_sig",  chkFnmocWW3_sig->isChecked());
+	Util::setSetting("downloadFnmocWW3_max",  chkFnmocWW3_max->isChecked());
+	Util::setSetting("downloadFnmocWW3_swl",  chkFnmocWW3_swl->isChecked());
+	Util::setSetting("downloadFnmocWW3_wnd",  chkFnmocWW3_wnd->isChecked());
+	Util::setSetting("downloadFnmocWW3_prim", chkFnmocWW3_prim->isChecked());
+	Util::setSetting("downloadFnmocWW3_scdy", chkFnmocWW3_scdy->isChecked());
+	Util::setSetting("downloadFnmocWW3_wcap", chkFnmocWW3_wcap->isChecked());
+	Util::setSetting ("downloadFnmocWW3_DataModel", waveDataModel);
+}
 //-------------------------------------------------------------------------------
 void DialogLoadGRIB::updateParameters ()
 {
     double tmp, xm, ym;
     
-    xmin = sbWest->cleanText().toDouble();
-    xmax = sbEast->cleanText().toDouble();
     ymin = sbNorth->cleanText().toDouble();
     ymax = sbSouth->cleanText().toDouble();
+    xmin = sbWest->cleanText().toDouble();
+    xmax = sbEast->cleanText().toDouble();
 
     resolution = cbResolution->currentText().toDouble();
     interval   = cbInterval->currentText().toInt();
@@ -341,61 +386,33 @@ void DialogLoadGRIB::updateParameters ()
     GUSTsfc      = chkGUSTsfc->isChecked();
     SUNSDsfc     = chkSUNSDsfc->isChecked();
 	
-	Util::setSetting("downloadIndResolution", cbResolution->currentIndex());
-	Util::setSetting("downloadIndInterval",  cbInterval->currentIndex());
-	Util::setSetting("downloadIndNbDays",  cbDays->currentIndex());
-	
-	Util::setSetting("downloadWind",  wind);
-	Util::setSetting("downloadPressure", pressure);
-	Util::setSetting("downloadRain",  rain);
-	Util::setSetting("downloadCloud", cloud);
-	Util::setSetting("downloadCloudLayers", cloudLayers);
-	Util::setSetting("downloadTemp",  temp);
-	Util::setSetting("downloadHumid", humid);
-	Util::setSetting("downloadIsotherm0", isotherm0);
-	
-	Util::setSetting("downloadTempMin",  tempMin);
-	Util::setSetting("downloadTempMax",  tempMax);
-	Util::setSetting("downloadSnowDepth", snowDepth);
-	Util::setSetting("downloadSnowCateg", snowCateg);
-	Util::setSetting("downloadFrzRainCateg", frzRainCateg);
-	Util::setSetting("downloadCAPEsfc", CAPEsfc);
-	Util::setSetting("downloadCINsfc", CINsfc);
-	Util::setSetting("downloadGUSTsfc", GUSTsfc);
-	Util::setSetting("downloadSUNSDsfc", SUNSDsfc);
-	
-	Util::setSetting("downloadAltitudeData200",  chkAltitude200->isChecked());
-	Util::setSetting("downloadAltitudeData300",  chkAltitude300->isChecked());
-	Util::setSetting("downloadAltitudeData500",  chkAltitude500->isChecked());
-	Util::setSetting("downloadAltitudeData700",  chkAltitude700->isChecked());
-	Util::setSetting("downloadAltitudeData850",  chkAltitude850->isChecked());
-	Util::setSetting("downloadAltitudeData925",  chkAltitude925->isChecked());
-	Util::setSetting("downloadSkewtData",  chkAltitude_SkewT->isChecked());
-	
-	Util::setSetting("downloadFnmocWW3_sig",  chkFnmocWW3_sig->isChecked());
-	Util::setSetting("downloadFnmocWW3_max",  chkFnmocWW3_max->isChecked());
-	Util::setSetting("downloadFnmocWW3_swl",  chkFnmocWW3_swl->isChecked());
-	Util::setSetting("downloadFnmocWW3_wnd",  chkFnmocWW3_wnd->isChecked());
-	Util::setSetting("downloadFnmocWW3_prim", chkFnmocWW3_prim->isChecked());
-	Util::setSetting("downloadFnmocWW3_scdy", chkFnmocWW3_scdy->isChecked());
-	Util::setSetting("downloadFnmocWW3_wcap", chkFnmocWW3_wcap->isChecked());
-
 	if (bt_FNMOC_WW3_GLB->isChecked())
 		waveDataModel = FNMOC_WW3_GLB;
 	else
 		waveDataModel = FNMOC_WW3_MED;
-	Util::setSetting ("downloadFnmocWW3_DataModel", waveDataModel);
+	
 }
 
 //-------------------------------------------------------------------------------
 void DialogLoadGRIB::slotParameterUpdated ()
 {
     updateParameters();
-    
-    int npts = (int) (  ceil(fabs(xmax-xmin)/resolution)
+	int npts = (int) (  ceil(fabs(xmax-xmin)/resolution)
                        * ceil(fabs(ymax-ymin)/resolution) );
     // Nombre de GribRecords
-    int nbrec = (int) days*24/interval +1;
+    int nbrec;
+
+	if (resolution < 0.5) {
+		if (days<=5)
+			nbrec = (int) days*24/interval +1;
+		else
+			nbrec = (int) ( 5*24/interval 
+						+ (days-5)*24/interval/4) +1;
+	}
+	else {
+		nbrec = (int) days*24/interval +1;
+	}
+	
     int nbPress = pressure ?  nbrec   : 0;
     int nbWind  = wind     ?  2*nbrec : 0;
     int nbRain  = rain     ?  nbrec-1 : 0;
@@ -450,16 +467,18 @@ void DialogLoadGRIB::slotParameterUpdated ()
 	int nbalt = 0;
 	if (chkAltitude200->isChecked()) nbalt++;
 	if (chkAltitude300->isChecked()) nbalt++;
+	if (chkAltitude400->isChecked()) nbalt++;
 	if (chkAltitude500->isChecked()) nbalt++;
+	if (chkAltitude600->isChecked()) nbalt++;
 	if (chkAltitude700->isChecked()) nbalt++;
 	if (chkAltitude850->isChecked()) nbalt++;
 	if (chkAltitude925->isChecked()) nbalt++;
-	nbits = 12;
+	nbits = 10;
 	estime += nbrec*nbalt*5*(head+(nbits*npts)/8+2 );
 	
 	int nbskewt = 0;
 	if (chkAltitude_SkewT->isChecked())
-		nbskewt = 21;
+		nbskewt = 32;
 	estime += nbrec*nbskewt*(head+(nbits*npts)/8+2 );
 
 	int nbwave = 0;
@@ -473,14 +492,21 @@ void DialogLoadGRIB::slotParameterUpdated ()
 	nbits = 6;
 	estime += nbrec*nbwave*(head+(nbits*npts)/8+2 );
 
-	estime = estime/1024;
-    slotGribMessage(tr("Size: %1 ko approx").arg(estime) );
+	double estimeko = estime/1024.0;	// size in ko
+	QString ssz;
+	if (estimeko <= 100)
+		ssz = QString("%1 Ko").arg(estimeko,0,'f',2);
+	else if (estimeko <= 1024)
+		ssz = QString("%1 Ko").arg(estimeko,0,'f',1);
+	else
+		ssz = QString("%1 Mo").arg(estimeko/1024.0,0,'f',1);
+	
+    slotGribMessage(tr("Size: ≃ ") + ssz + tr(" (max 100 Mo)"));
     
     if (estime == 0)
         btOK->setEnabled(false);
     else
         btOK->setEnabled(true);
-
 }
 //-------------------------------------------------------------------------------
 void DialogLoadGRIB::slotBtOK()
@@ -513,7 +539,9 @@ void DialogLoadGRIB::slotBtOK()
 					CAPEsfc, CINsfc,
 					chkAltitude200->isChecked(),
 					chkAltitude300->isChecked(),
+					chkAltitude400->isChecked(),
 					chkAltitude500->isChecked(),
+					chkAltitude600->isChecked(),
 					chkAltitude700->isChecked(),
 					chkAltitude850->isChecked(),
 					chkAltitude925->isChecked(),
@@ -524,6 +552,45 @@ void DialogLoadGRIB::slotBtOK()
 				);
 }
 //-------------------------------------------------------------------------------
+QString DialogLoadGRIB::createStringParameters ()
+{
+    QString parameters = "";
+    if (wind)
+        parameters += "W;";
+    if (pressure)
+        parameters += "P;";
+    if (rain)
+        parameters += "R;";
+    if (cloud)
+        parameters += "C;";
+    if (temp)
+        parameters += "T;";
+    if (humid)
+        parameters += "H;";
+	if (isotherm0)
+		parameters += "I;";
+    if (tempMin)
+        parameters += "m;";
+    if (tempMax)
+        parameters += "M;";
+    if (snowDepth)
+        parameters += "S;";
+    if (snowCateg)
+        parameters += "s;";
+    if (frzRainCateg)
+        parameters += "Z;";
+    if (CAPEsfc)
+        parameters += "c;";
+    if (CINsfc)
+        parameters += "i;";
+    if (GUSTsfc)
+        parameters += "G;";
+    if (SUNSDsfc)
+        parameters += "D;";
+	
+	return parameters;
+}
+//-------------------------------------------------------------------------------
 void DialogLoadGRIB::slotBtServerStatus ()
 {
     DialogServerStatus dial (networkManager, this);
@@ -557,7 +624,8 @@ void DialogLoadGRIB::setZone (double x0, double y0, double x1, double y1)
 	double tmp;
 	if (x0 > x1)  { tmp=x0; x0=x1; x1=tmp; }
 	if (y1 > y0)  { tmp=y0; y0=y1; y1=tmp; }	
-    sbNorth->setValue ( ceil(y0) );
+	
+    sbNorth->setValue ( ceil (y0) );
     sbSouth->setValue ( floor(y1) );
     sbWest->setValue  ( floor(x0) );
     sbEast->setValue  ( ceil (x1) );
@@ -610,7 +678,7 @@ QFrame *DialogLoadGRIB::createFrameButtonsZone(QWidget *parent)
 	//------------------------------------------------
     cbResolution = new QComboBox(this);
     assert(cbResolution);
-    cbResolution->addItems(QStringList()<< "0.5" << "1" << "2");
+    cbResolution->addItems(QStringList()<< "0.25"<< "0.5" << "1" << "2");
     cbResolution->setMinimumWidth (sizemin);
 	ind = Util::getSetting("downloadIndResolution", 0).toInt();
 	ind = Util::inRange(ind, 0, cbResolution->count()-1);
@@ -626,11 +694,25 @@ QFrame *DialogLoadGRIB::createFrameButtonsZone(QWidget *parent)
     
     cbDays = new QComboBox(this);
     assert(cbDays);
-    cbDays->addItems(QStringList()<< "1"<<"2"<<"3"<<"4"<<"5"<<"6"<<"7"<<"8");
+    cbDays->addItems(QStringList()<< "1"<<"2"<<"3"<<"4"<<"5"<<"6"<<"7"<<"8"<<"9"<<"10");
     cbDays->setMinimumWidth (sizemin);
 	ind = Util::getSetting("downloadIndNbDays", 7).toInt();	
 	ind = Util::inRange(ind, 0, cbDays->count()-1);
     cbDays->setCurrentIndex(ind);
+    
+    cbRunGFS = new QComboBox(this);
+    assert(cbRunGFS);
+	ind = 0;
+	cbRunGFS->insertItem (ind++, tr("Last"), "last");
+	cbRunGFS->insertItem (ind++, tr("0 hr"), "00");
+	cbRunGFS->insertItem (ind++, tr("6 hr"), "06");
+	cbRunGFS->insertItem (ind++, tr("12 hr"), "12");
+	cbRunGFS->insertItem (ind++, tr("18 hr"), "18");
+    cbRunGFS->setMinimumWidth (sizemin);
+	QString data = Util::getSetting("downloadRunGFS", "").toString();	
+	ind = cbRunGFS->findData (data);
+	ind = Util::inRange(ind, 0, cbRunGFS->count()-1);
+    cbRunGFS->setCurrentIndex (ind);
 
 	//------------------------------------------------
 	// Choix des données météo
@@ -700,9 +782,17 @@ QFrame *DialogLoadGRIB::createFrameButtonsZone(QWidget *parent)
     chkAltitude700  = new QCheckBox ("700 "+tr("hPa"));
     assert (chkAltitude700);
     chkAltitude700->setChecked  (Util::getSetting("downloadAltitudeData700", false).toBool());
+	
+    chkAltitude400  = new QCheckBox ("400 "+tr("hPa"));
+    assert (chkAltitude400);
+    chkAltitude400->setChecked  (Util::getSetting("downloadAltitudeData400", false).toBool());
     chkAltitude500  = new QCheckBox ("500 "+tr("hPa"));
     assert (chkAltitude500);
     chkAltitude500->setChecked  (Util::getSetting("downloadAltitudeData500", false).toBool());
+    chkAltitude600  = new QCheckBox ("600 "+tr("hPa"));
+    assert (chkAltitude600);
+    chkAltitude600->setChecked  (Util::getSetting("downloadAltitudeData600", false).toBool());
+	
     chkAltitude300  = new QCheckBox ("300 "+tr("hPa"));
     assert (chkAltitude300);
     chkAltitude300->setChecked  (Util::getSetting("downloadAltitudeData300", false).toBool());
@@ -717,8 +807,8 @@ QFrame *DialogLoadGRIB::createFrameButtonsZone(QWidget *parent)
     chkAltitude_All = new QCheckBox (tr("All"));
     assert (chkAltitude_All);
 	chkAltitude_All->setChecked  (
-		      chkAltitude200->isChecked() && chkAltitude300->isChecked() 
-		   && chkAltitude500->isChecked() && chkAltitude700->isChecked() 
+		      chkAltitude200->isChecked() && chkAltitude300->isChecked() && chkAltitude400->isChecked() 
+		   && chkAltitude500->isChecked() && chkAltitude600->isChecked() && chkAltitude700->isChecked() 
 		   && chkAltitude850->isChecked() && chkAltitude925->isChecked()
 		);
 	//----------------------------------------------------------------
@@ -805,21 +895,26 @@ QFrame *DialogLoadGRIB::createFrameButtonsZone(QWidget *parent)
     tlay = new QHBoxLayout(ftmp);
     assert(tlay);
 	tlay->setContentsMargins (0,0,0,0);
-		tlay->addWidget( new QLabel(tr("Resolution :")));
+		tlay->addWidget( new QLabel(tr("Resolution:")));
 		tlay->addWidget( cbResolution);
-		tlay->addWidget( new QLabel(tr(" °")));
+		tlay->addWidget( new QLabel(tr("°")));
 		//-------------------------
 		addSeparator (tlay, 'V'); 
 		//-------------------------
-		tlay->addWidget( new QLabel(tr("Interval :")));
+		tlay->addWidget( new QLabel(tr("Interval:")));
 		tlay->addWidget( cbInterval);
-		tlay->addWidget( new QLabel(tr(" hours")));
+		tlay->addWidget( new QLabel(tr("hours")));
 		//-------------------------
 		addSeparator (tlay, 'V'); 
 		//-------------------------
-		tlay->addWidget( new QLabel(tr("Period :")));
+		tlay->addWidget( new QLabel(tr("Period:")));
 		tlay->addWidget( cbDays);
-		tlay->addWidget( new QLabel(tr(" days")));
+		tlay->addWidget( new QLabel(tr("days")));
+		//-------------------------
+		addSeparator (tlay, 'V'); 
+		//-------------------------
+		tlay->addWidget( new QLabel(tr("GFS run:")));
+		tlay->addWidget( cbRunGFS);
     lay->addWidget( ftmp);
     //-------------------------
     addSeparator (lay, 'H'); 
@@ -889,9 +984,12 @@ QFrame *DialogLoadGRIB::createFrameButtonsZone(QWidget *parent)
 			gtmp->addWidget (chkAltitude925, 0,0);
 			gtmp->addWidget (chkAltitude850, 0,1);
 			gtmp->addWidget (chkAltitude700, 0,2);
-			gtmp->addWidget (chkAltitude500, 1,0);
-			gtmp->addWidget (chkAltitude300, 1,1);
-			gtmp->addWidget (chkAltitude200, 1,2);
+			gtmp->addWidget (chkAltitude600, 0,3);
+			
+			gtmp->addWidget (chkAltitude500, 1,1);
+			gtmp->addWidget (chkAltitude400, 1,0);
+			gtmp->addWidget (chkAltitude300, 1,2);
+			gtmp->addWidget (chkAltitude200, 1,3);
 		tlay->addWidget (fgrid);
 		addSeparator (tlay, 'V'); 
 		tlay->addWidget (chkAltitude_All);
@@ -937,8 +1035,6 @@ QFrame *DialogLoadGRIB::createFrameButtonsZone(QWidget *parent)
     //-------------------------
     labelMsg = new QLabel();
     lay->addWidget( labelMsg );
-    //lay->addWidget(new QLabel(tr("File size max: 20000 ko.")));
-    lay->addWidget(new QLabel(tr("File size max: ")+ "51200 Ko (50 Mo)"));
     //-------------------------
     addSeparator (lay, 'H'); 
     //-------------------------
