@@ -21,9 +21,12 @@
 // CurveDrawer: Constructor for single point
 //-------------------------------------------------------------------------------
 CurveDrawer::CurveDrawer( GriddedPlotter *plotter, 
-						  double lon, double lat, QWidget *parentWindow)
-:	QDialog(parentWindow)
+						  double lon, double lat)
+:	QWidget (NULL, Qt::Window) 
 {
+	setProperty ("objectType", "CurveDrawer");
+	setFocusPolicy(Qt::StrongFocus);
+	setWindowIcon (QIcon (Util::pathImg("zyGrib_32.xpm")));
 	initObj();
 
 	this->plotter	= plotter;
@@ -34,10 +37,12 @@ CurveDrawer::CurveDrawer( GriddedPlotter *plotter,
 	this->bSingle   = true;
 
 	initInterface();
-	
 	if( !privateConstructor() )
 		return;
 	
+	connect( qwtLegend,	SIGNAL(checked(const QVariant &, bool, int)), 
+			 this, SLOT( slotLegendChecked(const QVariant &, bool, int) ) );
+	
 	// display initial plot of wind speeds
 	if( createTable( GRB_WIND_SPEED ) ) {
 		initDataPlot( GRB_WIND_SPEED );
@@ -158,7 +163,7 @@ bool CurveDrawer::createTable( const int &iDataChosen )
 		if( bFirst ) { bFirst = false; dDir = dDirH; }
 		
 		// mangle 360 degree periodicity
-		qvWindDev << getInboundAngle(dDirH, dDir, false) / dStep;
+		qvWindDev << getInboundAngle(dDirH, dDir, true) / dStep;
 		dDir = dDirH;
 		delete pinfo;
 	}
@@ -338,12 +343,12 @@ void CurveDrawer::initDataPlot( const int &iDataChosen )
 	qwtCurve[1]->attach( qwtDataPlot );
 	
 	//------------------------------------------------------------------	
-	// set up 3rd plot on left y-axis for temperature plot
+	// set up 3rd plot on left y-axis for temperature plot 
 	//
 	qwtCurve[2]->setAxes( QwtPlot::xBottom, QwtPlot::yLeft );
-	qwtCurve[2]->setPen( QPen( QBrush( QColor(132,0,132,132), Qt::SolidPattern ), 1.4, 
-							  Qt::SolidLine, Qt::SquareCap, Qt::BevelJoin ) );
-	qwtCurve[2]->setStyle( QwtPlotCurve::Steps );
+	qwtCurve[2]->setPen( QPen( QBrush( QColor(255,0,0,132), Qt::SolidPattern ), 1.4, 
+							  Qt::SolidLine, Qt::SquareCap, Qt::BevelJoin ) ); /* color changed by francois-x */
+	qwtCurve[2]->setStyle( QwtPlotCurve::Lines );
 	if( reader->hasDataType( GRB_WIND_GUST )) {
 		qwtCurve[2]->setTitle( tr("Wind Gust") );
 		qwtCurve[2]->setSamples( *qvXAxis, qvTempMin );
@@ -354,9 +359,8 @@ void CurveDrawer::initDataPlot( const int &iDataChosen )
 	// set up 4th plot on left y-axis for temperature plot
 	//
 	qwtCurve[3]->setAxes( QwtPlot::xBottom, QwtPlot::yLeft );
-	qwtCurve[3]->setPen( QPen( QBrush( QColor(0,132,0,132), Qt::SolidPattern ), 1.4,
-							  Qt::SolidLine, Qt::SquareCap, Qt::BevelJoin ) );
-	qwtCurve[3]->setStyle( QwtPlotCurve::Steps );	
+	qwtCurve[3]->setPen( QPen( QColor(255,0,0,128) ) );
+	qwtCurve[3]->setStyle( QwtPlotCurve::Lines );
 	
 		
 	//------------------------------------------------------------------
@@ -397,7 +401,8 @@ void CurveDrawer::initDataPlot( const int &iDataChosen )
 									QwtPlotPicker::CrossRubberBand,
 									new QwtPickerClickRectMachine,
 									QwtPicker::ActiveOnly,									
-									qwtDataPlot->canvas(), dt,
+									qwtDataPlot->canvas(), 
+									dt,
 									qwtCurve[0]);
 	// connect signals
 //	connect(qwtPicker, SIGNAL(selected(const QwtDoublePoint &)), qwtPicker, SLOT(selected(const QwtDoublePoint &)));
@@ -405,7 +410,7 @@ void CurveDrawer::initDataPlot( const int &iDataChosen )
 	//------------------------------------------------------------------
 	// set up legend, activate curves
 	//
-	qwtLegend->setItemMode( QwtLegend::CheckableItem );
+	qwtLegend->setDefaultItemMode( QwtLegendData::Checkable );
 	qwtLegend->setLineWidth(10);
 	qwtDataPlot->insertLegend( qwtLegend, QwtPlot::BottomLegend );
 	activateLegend( qwtCurve[0], true );
@@ -432,25 +437,46 @@ void CurveDrawer::createDataPlot( const int &iDataChosen, const QString &sTitle
 	
 	// add min and max curve for temperature plot
 	if( iDataChosen == GRB_TEMP ) {
+	  	  qwtCurve[1]->detach(); 		  		  /* ADDED BY francois-x */
+		  qwtCurve[0]->setPen( QPen( QColor(0,0,255,255) ) ); /* ADDED BY francois-x */
         if( reader->hasDataType( GRB_TMIN ) ) {
-			qwtCurve[2]->setTitle( tr("Temp Min") );
+	    qwtCurve[2]->setTitle( tr("Temp Min") );
+	    qwtCurve[2]->setPen( QPen( QColor(0,0,255,128) ) );
             qwtCurve[2]->setSamples( *qvXAxis, qvTempMin );
             qwtCurve[2]->attach( qwtDataPlot );
             activateLegend( qwtCurve[2], true );
-        }
+        } else {
+		qwtCurve[2]->detach(); 	              		/* ADDED BY francois-x */
+	}
         if( reader->hasDataType( GRB_TMAX ) ) {
             qwtCurve[3]->setSamples( *qvXAxis, qvTempMax );
             qwtCurve[3]->attach( qwtDataPlot );
 			activateLegend( qwtCurve[3], true );
-        }
+        } else {
+		qwtCurve[3]->detach();					/* ADDED BY francois-x */
+	}
+	
+	
 	} else if( iDataChosen == GRB_WIND_SPEED ) {
+	qwtCurve[0]->setPen( QPen( QColor(0,0,255,128) ) );
+	qwtCurve[3]->detach();						/* ADDED BY francois-x */
+	qwtCurve[1]->setTitle( tr("Wind Deviation") );		/* ADDED BY francois-x */
+	qwtCurve[1]->setSamples( *qvXAxis, *qvY2Axis );		/* ADDED BY francois-x */
+	qwtCurve[1]->attach( qwtDataPlot );		   		/* ADDED BY francois-x */
+	activateLegend( qwtCurve[1], false );	   	   		/* ADDED BY francois-x */
+	
         if( reader->hasDataType( GRB_WIND_GUST ) ) {
-			qwtCurve[2]->setTitle( tr("Wind Gust") );
+	    qwtCurve[2]->setTitle( tr("Wind Gust") );
+	    qwtCurve[2]->setPen( QPen( QBrush( QColor(255,0,0,132), Qt::SolidPattern ), 1.4, 
+							  Qt::SolidLine, Qt::SquareCap, Qt::BevelJoin ) ); /* ADDED BY francois-x */
             qwtCurve[2]->setSamples( *qvXAxis, qvTempMin );
             qwtCurve[2]->attach( qwtDataPlot );
             activateLegend( qwtCurve[2], true );
         }
+        
 	} else {
+		qwtCurve[0]->setPen( QPen( QColor(0,0,0,255) ) );	/* ADDED BY francois-x */
+		qwtCurve[1]->detach(); 		   		/* ADDED BY francois-x */
 		qwtCurve[2]->detach();
 		qwtCurve[3]->detach();
 	}
@@ -558,9 +584,10 @@ void CurveDrawer::slotSelectTrack( int iSelectedTrack )
 // slot for legend item checking
 // toggle legend item check box and do replot
 //-------------------------------------------------------------------------------
-void CurveDrawer::slotLegendChecked( QwtPlotItem *pItem, bool on )
+void CurveDrawer::slotLegendChecked(const QVariant &itemInfo, bool on, int /*index*/)
 {
-	activateLegend( pItem, on );
+	QwtPlotItem *item = qwtDataPlot->infoToItem(itemInfo);
+	activateLegend( item, on );
 	qwtDataPlot->replot();	
 }
 //-------------------------------------------------------------------------------
@@ -588,11 +615,13 @@ void CurveDrawer::activateLegend( QwtPlotItem *pItem, bool on )
 	} else {
 		pItem->setVisible( on );
 	}
-	// check legend button
-	QWidget *qWid = qwtDataPlot->legend()->find( pItem );
-	if( qWid && qWid->inherits( "QwtLegendItem" ) )
-		((QwtLegendItem *)qWid)->setChecked( on );
 	
+	// check legend button
+	QWidget *w = qwtLegend->legendWidget(qwtDataPlot->itemToInfo(pItem));
+	QwtLegendLabel *lgdItem = dynamic_cast<QwtLegendLabel*>(w);
+	if (lgdItem) {
+		lgdItem->setChecked( on );
+	}
 }
 //-------------------------------------------------------------------------------
 // get data unit for axis title
@@ -631,7 +660,7 @@ QString CurveDrawer::getPlotUnit( const int &iDataChosen )
 void CurveDrawer::appendCurves( const int &iDataChosen, const DataPointInfo *pinfo )
 {
 	if( iDataChosen == GRB_WIND_SPEED ) {
-		qvY1Axis  << pinfo->windSpeed_10m;
+		qvY1Axis << convertData( GRB_WIND_SPEED,pinfo->windSpeed_10m);
 		if( reader->hasDataType( GRB_WIND_GUST ) ) {
 			qvTempMin << convertData( GRB_WIND_GUST, pinfo->getDataValue( DataCode(GRB_WIND_GUST,LV_ABOV_GND,0) ));
 		}
@@ -658,8 +687,8 @@ float CurveDrawer::convertData( const int &iDataKey, const float &fDataVal ) {
     switch( iDataKey ) {
         case GRB_WIND_SPEED:
 		case GRB_WIND_GUST:
-            fVal = Util::formatSpeed( fDataVal, false ).toFloat( &bConv );
-            return bConv ? fVal : fDataVal;
+			fVal = Util::formatSpeed_Wind( fDataVal, false).toFloat( &bConv );
+			return bConv ? fVal : fDataVal;
             
         case GRB_TEMP:
         case GRB_TMIN:
@@ -681,11 +710,17 @@ float CurveDrawer::convertData( const int &iDataKey, const float &fDataVal ) {
 float CurveDrawer::getInboundAngle( const float &fAngle1, const float &fAngle2, bool bAbs )
 {
 	float fDiff;
+	float sfDiff;
+	sfDiff = 0.;
 	fDiff = bAbs ? qAbs(fAngle1 - fAngle2) : (fAngle1 - fAngle2);
-	if( qAbs(fAngle1 - fAngle2) > 180. )
-		return (360. - fDiff);
+	if (fmod(fAngle1+fDiff,360.) == fAngle2)
+	  sfDiff = 1.;
 	else
-		return fDiff;
+	  sfDiff = -1.;
+	if( qAbs(fAngle1 - fAngle2) > 180. )
+		return (sfDiff*(360. - fDiff));
+	else
+		return (sfDiff*fDiff);
 }
 //-------------------------------------------------------------------------------
 // additional constructor
@@ -725,7 +760,7 @@ bool CurveDrawer::privateConstructor()
 	//----------------------------------------------
 	// Constructor of for all used objects
 	qwtCurve[0]  = new QwtPlotCurve( tr("Wind Speed") );
-	qwtCurve[1]	 = new QwtPlotCurve( tr("Wind Direction") );
+	qwtCurve[1]  = new QwtPlotCurve( tr("Wind Direction") );
 	qwtCurve[2]  = new QwtPlotCurve( tr("Temp Min") );
 	qwtCurve[3]  = new QwtPlotCurve( tr("Temp Max") );	
 	qwtYScale[0] = new QwtLinearScaleEngine();
@@ -739,8 +774,8 @@ bool CurveDrawer::privateConstructor()
 	if( reader->hasDataType( GRB_PRESSURE_MSL ) )	{ myToolBar->cbData->addItem(tr("Pressure"), GRB_PRESSURE_MSL ); };
 	if( reader->hasDataType( GRB_TEMP ) )			{ myToolBar->cbData->addItem(tr("Temperature"), GRB_TEMP ); };
 	if( reader->hasDataType( GRB_CLOUD_TOT ) )		{ myToolBar->cbData->addItem(tr("Cloud cover"), GRB_CLOUD_TOT ); };
-	if( reader->hasDataType( GRB_PRECIP_RATE ))		{ myToolBar->cbData->addItem(tr("Percipitation Rate"), GRB_PRECIP_RATE ); };
-	if( reader->hasDataType( GRB_PRECIP_TOT ) )		{ myToolBar->cbData->addItem(tr("Percipitation Total"), GRB_PRECIP_TOT ); };
+	if( reader->hasDataType( GRB_PRECIP_RATE ))		{ myToolBar->cbData->addItem(tr("Precipitation Rate"), GRB_PRECIP_RATE ); };
+	if( reader->hasDataType( GRB_PRECIP_TOT ) )		{ myToolBar->cbData->addItem(tr("Precipitation Total"), GRB_PRECIP_TOT ); };
 	
 	return true;
 }
@@ -791,7 +826,6 @@ void CurveDrawer::initInterface()
 	sizePolicy.setVerticalStretch(1);
 	this->setSizePolicy(sizePolicy);
 	this->setBaseSize(QSize(939, 736));
-	this->setModal(true);
 	this->setContentsMargins(0, 0, 0, 0);
 
 	/* Ist funktioniert, bis auf Maximierung des DataPlots
@@ -847,9 +881,9 @@ void CurveDrawer::initInterface()
 	connect( myToolBar->cbData,	SIGNAL(activated(int)),			this, SLOT(slotDataChosen(int)) );
 	// OpenCPN
 //	connect( myToolBar->cbWayPoints, SIGNAL(activated(int)),	this, SLOT(slotSelectTrack(int)) );	
-	connect( qwtDataPlot,	SIGNAL(legendChecked( QwtPlotItem*, bool ) ), this,
-            SLOT( slotLegendChecked( QwtPlotItem*, bool ) ) );
 	
+// 	connect( qwtDataPlot,	SIGNAL(legendChecked( QwtPlotItem*, bool ) ), this,
+//             SLOT( slotLegendChecked( QwtPlotItem*, bool ) ) );
 }
 /*
  *=========================================================================================
