@@ -17,6 +17,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #include <unistd.h>
+#include <time.h>
+
 #include <QDir>
 #include <QStringList>
 
@@ -24,11 +26,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QNetworkProxy>
 #include <QNetworkProxyQuery>
 #include <QCryptographicHash>
+#include <QFileDialog>
 
 #include "Settings.h"
 #include "Util.h"
 #include "Version.h"
 
+
 //======================================================================
 QHash <QString, QVariant> GLOB_hashSettings;
 
@@ -51,8 +55,52 @@ QVariant Util::getSetting (const QString &key, const QVariant &defaultValue)
 		return v;
 	}
 }
-
 //========================================================================
+QString Util::getSaveFileName (QWidget *parent, const QString &caption, 
+							const QString &dir, const QString &filter)
+{
+	#ifdef Q_OS_MACX
+		if ( QSysInfo::MacintoshVersion > QSysInfo::MV_10_8 )
+		{   // fix Mac OS X 10.9 (mavericks) QFileDialog bug
+			int useNative = Util::getSetting("mac_useNativeFileDialog", 999).toInt();
+			if (useNative == 999) {
+				Util::setSetting("mac_useNativeFileDialog", 0);
+				useNative = 0;
+			}
+			if (useNative == 0) {
+				return QFileDialog::getSaveFileName (parent, caption, dir, filter, 
+							0, QFileDialog::DontUseNativeDialog);
+			}
+		}
+	#endif
+	return QFileDialog::getSaveFileName (parent, caption, dir, filter);
+}
+//------------------------------------------------------------
+QString Util::getOpenFileName (QWidget *parent, const QString &caption, 
+							const QString &dir, const QString &filter)
+{
+	#ifdef Q_OS_MACX
+		if ( QSysInfo::MacintoshVersion > QSysInfo::MV_10_8 )
+		{   // fix Mac OS X 10.9 (mavericks) QFileDialog bug
+			int useNative = Util::getSetting("mac_useNativeFileDialog", 999).toInt();
+			if (useNative == 999) {
+				Util::setSetting("mac_useNativeFileDialog", 0);
+				useNative = 0;
+			}
+			if (useNative == 0) {
+				return QFileDialog::getOpenFileName (parent, caption, dir, filter, 
+							0, QFileDialog::DontUseNativeDialog);
+			}
+		}
+	#endif
+	return QFileDialog::getOpenFileName (parent, caption, dir, filter);
+}
+//------------------------------------------------------------
+QString Util::getServerName ()
+{
+	return "www.zygrib.org";
+}
+//------------------------------------------------------------
 void Util::setApplicationProxy ()
 {
 	QNetworkProxy proxy;
@@ -68,7 +116,7 @@ void Util::setApplicationProxy ()
 		
 		if (proxy.type() == QNetworkProxy::DefaultProxy)
 		{
-			QNetworkProxyQuery proxq = QNetworkProxyQuery (QUrl("http://www.zygrib.org/index.php"));
+			QNetworkProxyQuery proxq = QNetworkProxyQuery (QUrl("http://"+getServerName()+"/index.php"));
 			QList<QNetworkProxy> list = QNetworkProxyFactory::systemProxyForQuery (proxq);
 			if (list.size() > 0) {
 				QNetworkProxy pr2 = list [0];
@@ -101,11 +149,7 @@ QNetworkRequest Util::makeNetworkRequest (QString url,double x0,double y0,double
 		QString zp = Util::encode(Util::decode(Util::getSetting("zyGribForumUserPassword", "").toString()),now);
 		url += "&zl="+zl+"&zp="+zp+"&md=h";
 		request.setRawHeader ("User-Agent","Mozilla/5.0 (Windows NT 5.1; rv:8.0) Gecko/20100101 Firefox/8.0");
-		request.setRawHeader ("Accept","text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
-		request.setRawHeader ("Accept-Language","fr-ch,fr;q=0.8,fr-fr;q=0.6,en-us;q=0.4,en;q=0.2");
-		request.setRawHeader ("Accept-Encoding","gzip, deflate");
-		request.setRawHeader ("Accept-Charset","ISO-8859-1,utf-8;q=0.7,*;q=0.7");
-		request.setRawHeader ("Cache-Control","max-stale=0");
+ 		request.setRawHeader ("Accept","text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
 	}
 	else
 		request.setRawHeader ("User-Agent",qPrintable(Version::getAppName()+"/"+Version::getVersion()) );
@@ -317,9 +361,11 @@ QString Util::getDataUnit (const DataCode &dtc)
 		case GRB_PRV_THETA_E      : 
 			return Util::getSetting("unitsTemp", tr("°C")).toString();
 			break;
-		case GRB_WIND_VX      : 
-		case GRB_WIND_VY      : 
-		case GRB_PRV_WIND_XY2D    : 
+		case GRB_WIND_VX    : 
+		case GRB_WIND_VY    : 
+		case GRB_WIND_SPEED : 
+		case GRB_PRV_WIND_XY2D : 
+		case GRB_PRV_WIND_JET  : 
 			return Util::getSetting("unitsWindSpeed", tr("km/h")).toString();
 			break;
 		case GRB_CUR_VX      : 
@@ -350,6 +396,7 @@ QString Util::getDataUnit (const DataCode &dtc)
 		case GRB_WAV_MAX_HT : 
 			return tr("m");
 			break;
+		case GRB_WIND_DIR : 
 		case GRB_WAV_WND_DIR : 
 		case GRB_WAV_SWL_DIR : 
 		case GRB_WAV_MAX_DIR : 
@@ -433,7 +480,7 @@ QString Util::formatCAPEsfc (float jkg, bool withUnit)
 {
     QString unite = Util::getDataUnit (DataCode(GRB_CAPE,LV_GND_SURF,0));
     QString r;
-	r.sprintf("%d", (int) jkg);
+	r.sprintf("%d", qRound(jkg));
 	return (withUnit) ? r+" "+unite : r;
 }
 //----------------------------------------------------------------
@@ -663,10 +710,10 @@ int  Util::getDayNum (time_t t)
 	return dt.date().dayOfWeek();
 }
 //------------------------------------------------
-QString Util::formatDateLong (time_t t, bool setLocalTime)
+QString Util::formatDateLong (time_t t, bool localTime)
 {
     QDateTime dt;
-	if (setLocalTime)
+	if (localTime)
 		dt = applyTimeZone(t);
 	else
 		dt.setTime_t(t);
@@ -798,9 +845,24 @@ double Util::roundMultiple (double x, double mul)
 	}
 	return sg * ((int)floor(x/mul+0.5))*mul;
 }
-
-
-
+//----------------------------------------------------------------
+time_t Util::timestampSetHour (time_t t, int hour, int min, int sec)
+{
+	struct tm dt;
+	memcpy (&dt, gmtime(&t), sizeof(struct tm)); // no gmtime_r in windows mingw
+	dt.tm_hour = hour;
+	dt.tm_min = min;
+	dt.tm_sec = sec;
+	return mktime (&dt);
+}
+//------------------------------------
+void Util::dumpchars (unsigned char *buf, size_t offset, size_t len)
+{
+	for (size_t i=0; i<len; i++) {
+		unsigned char c = buf[i+offset];
+		printf ("0x%02X %c\n", c, (c>=32?c:' '));
+	}
+}
 
 
 
